summaryrefslogtreecommitdiff
path: root/content/fetch.c
diff options
context:
space:
mode:
Diffstat (limited to 'content/fetch.c')
-rw-r--r--content/fetch.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/content/fetch.c b/content/fetch.c
index decb261a7..11adf9cf4 100644
--- a/content/fetch.c
+++ b/content/fetch.c
@@ -379,8 +379,9 @@ fetcher_add(lwc_string *scheme, const struct fetcher_operation_table *ops)
return NSERROR_OK;
}
-/* exported interface documented in content/fetchers.h */
-nserror fetcher_fdset(fd_set *read_fd_set,
+/* exported interface documented in content/fetch.h */
+nserror
+fetch_fdset(fd_set *read_fd_set,
fd_set *write_fd_set,
fd_set *except_fd_set,
int *maxfd_out)